# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .annotation import (
    Annotation,
    AnnotationMetadata,
    AnnotationValue,
    BoundingPoly,
    ImageBoundingPolyAnnotation,
    ImageClassificationAnnotation,
    ImagePolylineAnnotation,
    ImageSegmentationAnnotation,
    NormalizedBoundingPoly,
    NormalizedPolyline,
    NormalizedVertex,
    ObjectTrackingFrame,
    OperatorMetadata,
    Polyline,
    SequentialSegment,
    TextClassificationAnnotation,
    TextEntityExtractionAnnotation,
    TimeSegment,
    Vertex,
    VideoClassificationAnnotation,
    VideoEventAnnotation,
    VideoObjectTrackingAnnotation,
    AnnotationSentiment,
    AnnotationSource,
    AnnotationType,
)
from .annotation_spec_set import (
    AnnotationSpec,
    AnnotationSpecSet,
)
from .data_labeling_service import (
    CreateAnnotationSpecSetRequest,
    CreateDatasetRequest,
    CreateEvaluationJobRequest,
    CreateInstructionRequest,
    DeleteAnnotatedDatasetRequest,
    DeleteAnnotationSpecSetRequest,
    DeleteDatasetRequest,
    DeleteEvaluationJobRequest,
    DeleteInstructionRequest,
    ExportDataRequest,
    GetAnnotatedDatasetRequest,
    GetAnnotationSpecSetRequest,
    GetDataItemRequest,
    GetDatasetRequest,
    GetEvaluationJobRequest,
    GetEvaluationRequest,
    GetExampleRequest,
    GetInstructionRequest,
    ImportDataRequest,
    LabelImageRequest,
    LabelTextRequest,
    LabelVideoRequest,
    ListAnnotatedDatasetsRequest,
    ListAnnotatedDatasetsResponse,
    ListAnnotationSpecSetsRequest,
    ListAnnotationSpecSetsResponse,
    ListDataItemsRequest,
    ListDataItemsResponse,
    ListDatasetsRequest,
    ListDatasetsResponse,
    ListEvaluationJobsRequest,
    ListEvaluationJobsResponse,
    ListExamplesRequest,
    ListExamplesResponse,
    ListInstructionsRequest,
    ListInstructionsResponse,
    PauseEvaluationJobRequest,
    ResumeEvaluationJobRequest,
    SearchEvaluationsRequest,
    SearchEvaluationsResponse,
    SearchExampleComparisonsRequest,
    SearchExampleComparisonsResponse,
    UpdateEvaluationJobRequest,
)
from .data_payloads import (
    ImagePayload,
    TextPayload,
    VideoPayload,
    VideoThumbnail,
)
from .dataset import (
    AnnotatedDataset,
    AnnotatedDatasetMetadata,
    BigQuerySource,
    ClassificationMetadata,
    DataItem,
    Dataset,
    Example,
    GcsDestination,
    GcsFolderDestination,
    GcsSource,
    InputConfig,
    LabelStats,
    OutputConfig,
    TextMetadata,
    DataType,
)
from .evaluation import (
    BoundingBoxEvaluationOptions,
    ClassificationMetrics,
    ConfusionMatrix,
    Evaluation,
    EvaluationConfig,
    EvaluationMetrics,
    ObjectDetectionMetrics,
    PrCurve,
)
from .evaluation_job import (
    Attempt,
    EvaluationJob,
    EvaluationJobAlertConfig,
    EvaluationJobConfig,
)
from .human_annotation_config import (
    BoundingPolyConfig,
    EventConfig,
    HumanAnnotationConfig,
    ImageClassificationConfig,
    ObjectDetectionConfig,
    ObjectTrackingConfig,
    PolylineConfig,
    SegmentationConfig,
    SentimentConfig,
    TextClassificationConfig,
    TextEntityExtractionConfig,
    VideoClassificationConfig,
    StringAggregationType,
)
from .instruction import (
    CsvInstruction,
    Instruction,
    PdfInstruction,
)
from .operations import (
    CreateInstructionMetadata,
    ExportDataOperationMetadata,
    ExportDataOperationResponse,
    ImportDataOperationMetadata,
    ImportDataOperationResponse,
    LabelImageBoundingBoxOperationMetadata,
    LabelImageBoundingPolyOperationMetadata,
    LabelImageClassificationOperationMetadata,
    LabelImageOrientedBoundingBoxOperationMetadata,
    LabelImagePolylineOperationMetadata,
    LabelImageSegmentationOperationMetadata,
    LabelOperationMetadata,
    LabelTextClassificationOperationMetadata,
    LabelTextEntityExtractionOperationMetadata,
    LabelVideoClassificationOperationMetadata,
    LabelVideoEventOperationMetadata,
    LabelVideoObjectDetectionOperationMetadata,
    LabelVideoObjectTrackingOperationMetadata,
)

__all__ = (
    "Annotation",
    "AnnotationMetadata",
    "AnnotationValue",
    "BoundingPoly",
    "ImageBoundingPolyAnnotation",
    "ImageClassificationAnnotation",
    "ImagePolylineAnnotation",
    "ImageSegmentationAnnotation",
    "NormalizedBoundingPoly",
    "NormalizedPolyline",
    "NormalizedVertex",
    "ObjectTrackingFrame",
    "OperatorMetadata",
    "Polyline",
    "SequentialSegment",
    "TextClassificationAnnotation",
    "TextEntityExtractionAnnotation",
    "TimeSegment",
    "Vertex",
    "VideoClassificationAnnotation",
    "VideoEventAnnotation",
    "VideoObjectTrackingAnnotation",
    "AnnotationSentiment",
    "AnnotationSource",
    "AnnotationType",
    "AnnotationSpec",
    "AnnotationSpecSet",
    "CreateAnnotationSpecSetRequest",
    "CreateDatasetRequest",
    "CreateEvaluationJobRequest",
    "CreateInstructionRequest",
    "DeleteAnnotatedDatasetRequest",
    "DeleteAnnotationSpecSetRequest",
    "DeleteDatasetRequest",
    "DeleteEvaluationJobRequest",
    "DeleteInstructionRequest",
    "ExportDataRequest",
    "GetAnnotatedDatasetRequest",
    "GetAnnotationSpecSetRequest",
    "GetDataItemRequest",
    "GetDatasetRequest",
    "GetEvaluationJobRequest",
    "GetEvaluationRequest",
    "GetExampleRequest",
    "GetInstructionRequest",
    "ImportDataRequest",
    "LabelImageRequest",
    "LabelTextRequest",
    "LabelVideoRequest",
    "ListAnnotatedDatasetsRequest",
    "ListAnnotatedDatasetsResponse",
    "ListAnnotationSpecSetsRequest",
    "ListAnnotationSpecSetsResponse",
    "ListDataItemsRequest",
    "ListDataItemsResponse",
    "ListDatasetsRequest",
    "ListDatasetsResponse",
    "ListEvaluationJobsRequest",
    "ListEvaluationJobsResponse",
    "ListExamplesRequest",
    "ListExamplesResponse",
    "ListInstructionsRequest",
    "ListInstructionsResponse",
    "PauseEvaluationJobRequest",
    "ResumeEvaluationJobRequest",
    "SearchEvaluationsRequest",
    "SearchEvaluationsResponse",
    "SearchExampleComparisonsRequest",
    "SearchExampleComparisonsResponse",
    "UpdateEvaluationJobRequest",
    "ImagePayload",
    "TextPayload",
    "VideoPayload",
    "VideoThumbnail",
    "AnnotatedDataset",
    "AnnotatedDatasetMetadata",
    "BigQuerySource",
    "ClassificationMetadata",
    "DataItem",
    "Dataset",
    "Example",
    "GcsDestination",
    "GcsFolderDestination",
    "GcsSource",
    "InputConfig",
    "LabelStats",
    "OutputConfig",
    "TextMetadata",
    "DataType",
    "BoundingBoxEvaluationOptions",
    "ClassificationMetrics",
    "ConfusionMatrix",
    "Evaluation",
    "EvaluationConfig",
    "EvaluationMetrics",
    "ObjectDetectionMetrics",
    "PrCurve",
    "Attempt",
    "EvaluationJob",
    "EvaluationJobAlertConfig",
    "EvaluationJobConfig",
    "BoundingPolyConfig",
    "EventConfig",
    "HumanAnnotationConfig",
    "ImageClassificationConfig",
    "ObjectDetectionConfig",
    "ObjectTrackingConfig",
    "PolylineConfig",
    "SegmentationConfig",
    "SentimentConfig",
    "TextClassificationConfig",
    "TextEntityExtractionConfig",
    "VideoClassificationConfig",
    "StringAggregationType",
    "CsvInstruction",
    "Instruction",
    "PdfInstruction",
    "CreateInstructionMetadata",
    "ExportDataOperationMetadata",
    "ExportDataOperationResponse",
    "ImportDataOperationMetadata",
    "ImportDataOperationResponse",
    "LabelImageBoundingBoxOperationMetadata",
    "LabelImageBoundingPolyOperationMetadata",
    "LabelImageClassificationOperationMetadata",
    "LabelImageOrientedBoundingBoxOperationMetadata",
    "LabelImagePolylineOperationMetadata",
    "LabelImageSegmentationOperationMetadata",
    "LabelOperationMetadata",
    "LabelTextClassificationOperationMetadata",
    "LabelTextEntityExtractionOperationMetadata",
    "LabelVideoClassificationOperationMetadata",
    "LabelVideoEventOperationMetadata",
    "LabelVideoObjectDetectionOperationMetadata",
    "LabelVideoObjectTrackingOperationMetadata",
)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.datalabeling.v1beta1",
    manifest={"AnnotationSpecSet", "AnnotationSpec",},
)


class AnnotationSpecSet(proto.Message):
    r"""An AnnotationSpecSet is a collection of label definitions.
    For example, in image classification tasks, you define a set of
    possible labels for images as an AnnotationSpecSet. An
    AnnotationSpecSet is immutable upon creation.

    Attributes:
        name (str):
            Output only. The AnnotationSpecSet resource name in the
            following format:

            "projects/{project_id}/annotationSpecSets/{annotation_spec_set_id}".
        display_name (str):
            Required. The display name for
            AnnotationSpecSet that you define when you
            create it. Maximum of 64 characters.
        description (str):
            Optional. User-provided description of the
            annotation specification set. The description
            can be up to 10,000 characters long.
        annotation_specs (Sequence[google.cloud.datalabeling_v1beta1.types.AnnotationSpec]):
            Required. The array of AnnotationSpecs that
            you define when you create the
            AnnotationSpecSet. These are the possible labels
            for the labeling task.
        blocking_resources (Sequence[str]):
            Output only. The names of any related
            resources that are blocking changes to the
            annotation spec set.
    """

    name = proto.Field(proto.STRING, number=1,)
    display_name = proto.Field(proto.STRING, number=2,)
    description = proto.Field(proto.STRING, number=3,)
    annotation_specs = proto.RepeatedField(
        proto.MESSAGE, number=4, message="AnnotationSpec",
    )
    blocking_resources = proto.RepeatedField(proto.STRING, number=5,)


class AnnotationSpec(proto.Message):
    r"""Container of information related to one possible annotation that can
    be used in a labeling task. For example, an image classification
    task where images are labeled as ``dog`` or ``cat`` must reference
    an AnnotationSpec for ``dog`` and an AnnotationSpec for ``cat``.

    Attributes:
        display_name (str):
            Required. The display name of the
            AnnotationSpec. Maximum of 64 characters.
        description (str):
            Optional. User-provided description of the
            annotation specification. The description can be
            up to 10,000 characters long.
    """

    display_name = proto.Field(proto.STRING, number=1,)
    description = proto.Field(proto.STRING, number=2,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.datalabeling_v1beta1.types import (
    annotation_spec_set as gcd_annotation_spec_set,
)
from google.cloud.datalabeling_v1beta1.types import dataset as gcd_dataset
from google.cloud.datalabeling_v1beta1.types import evaluation
from google.cloud.datalabeling_v1beta1.types import evaluation_job as gcd_evaluation_job
from google.cloud.datalabeling_v1beta1.types import human_annotation_config
from google.cloud.datalabeling_v1beta1.types import instruction as gcd_instruction
from google.protobuf import field_mask_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.datalabeling.v1beta1",
    manifest={
        "CreateDatasetRequest",
        "GetDatasetRequest",
        "ListDatasetsRequest",
        "ListDatasetsResponse",
        "DeleteDatasetRequest",
        "ImportDataRequest",
        "ExportDataRequest",
        "GetDataItemRequest",
        "ListDataItemsRequest",
        "ListDataItemsResponse",
        "GetAnnotatedDatasetRequest",
        "ListAnnotatedDatasetsRequest",
        "ListAnnotatedDatasetsResponse",
        "DeleteAnnotatedDatasetRequest",
        "LabelImageRequest",
        "LabelVideoRequest",
        "LabelTextRequest",
        "GetExampleRequest",
        "ListExamplesRequest",
        "ListExamplesResponse",
        "CreateAnnotationSpecSetRequest",
        "GetAnnotationSpecSetRequest",
        "ListAnnotationSpecSetsRequest",
        "ListAnnotationSpecSetsResponse",
        "DeleteAnnotationSpecSetRequest",
        "CreateInstructionRequest",
        "GetInstructionRequest",
        "DeleteInstructionRequest",
        "ListInstructionsRequest",
        "ListInstructionsResponse",
        "GetEvaluationRequest",
        "SearchEvaluationsRequest",
        "SearchEvaluationsResponse",
        "SearchExampleComparisonsRequest",
        "SearchExampleComparisonsResponse",
        "CreateEvaluationJobRequest",
        "UpdateEvaluationJobRequest",
        "GetEvaluationJobRequest",
        "PauseEvaluationJobRequest",
        "ResumeEvaluationJobRequest",
        "DeleteEvaluationJobRequest",
        "ListEvaluationJobsRequest",
        "ListEvaluationJobsResponse",
    },
)


class CreateDatasetRequest(proto.Message):
    r"""Request message for CreateDataset.
    Attributes:
        parent (str):
            Required. Dataset resource parent, format:
            projects/{project_id}
        dataset (google.cloud.datalabeling_v1beta1.types.Dataset):
            Required. The dataset to be created.
    """

    parent = proto.Field(proto.STRING, number=1,)
    dataset = proto.Field(proto.MESSAGE, number=2, message=gcd_dataset.Dataset,)


class GetDatasetRequest(proto.Message):
    r"""Request message for GetDataSet.
    Attributes:
        name (str):
            Required. Dataset resource name, format:
            projects/{project_id}/datasets/{dataset_id}
    """

    name = proto.Field(proto.STRING, number=1,)


class ListDatasetsRequest(proto.Message):
    r"""Request message for ListDataset.
    Attributes:
        parent (str):
            Required. Dataset resource parent, format:
            projects/{project_id}
        filter (str):
            Optional. Filter on dataset is not supported
            at this moment.
        page_size (int):
            Optional. Requested page size. Server may
            return fewer results than requested. Default
            value is 100.
        page_token (str):
            Optional. A token identifying a page of results for the
            server to return. Typically obtained by
            [ListDatasetsResponse.next_page_token][google.cloud.datalabeling.v1beta1.ListDatasetsResponse.next_page_token]
            of the previous [DataLabelingService.ListDatasets] call.
            Returns the first page if empty.
    """

    parent = proto.Field(proto.STRING, number=1,)
    filter = proto.Field(proto.STRING, number=2,)
    page_size = proto.Field(proto.INT32, number=3,)
    page_token = proto.Field(proto.STRING, number=4,)


class ListDatasetsResponse(proto.Message):
    r"""Results of listing datasets within a project.
    Attributes:
        datasets (Sequence[google.cloud.datalabeling_v1beta1.types.Dataset]):
            The list of datasets to return.
        next_page_token (str):
            A token to retrieve next page of results.
    """

    @property
    def raw_page(self):
        return self

    datasets = proto.RepeatedField(
        proto.MESSAGE, number=1, message=gcd_dataset.Dataset,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class DeleteDatasetRequest(proto.Message):
    r"""Request message for DeleteDataset.
    Attributes:
        name (str):
            Required. Dataset resource name, format:
            projects/{project_id}/datasets/{dataset_id}
    """

    name = proto.Field(proto.STRING, number=1,)


class ImportDataRequest(proto.Message):
    r"""Request message for ImportData API.
    Attributes:
        name (str):
            Required. Dataset resource name, format:
            projects/{project_id}/datasets/{dataset_id}
        input_config (google.cloud.datalabeling_v1beta1.types.InputConfig):
            Required. Specify the input source of the
            data.
        user_email_address (str):
            Email of the user who started the import task
            and should be notified by email. If empty no
            notification will be sent.
    """

    name = proto.Field(proto.STRING, number=1,)
    input_config = proto.Field(
        proto.MESSAGE, number=2, message=gcd_dataset.InputConfig,
    )
    user_email_address = proto.Field(proto.STRING, number=3,)


class ExportDataRequest(proto.Message):
    r"""Request message for ExportData API.
    Attributes:
        name (str):
            Required. Dataset resource name, format:
            projects/{project_id}/datasets/{dataset_id}
        annotated_dataset (str):
            Required. Annotated dataset resource name. DataItem in
            Dataset and their annotations in specified annotated dataset
            will be exported. It's in format of
            projects/{project_id}/datasets/{dataset_id}/annotatedDatasets/
            {annotated_dataset_id}
        filter (str):
            Optional. Filter is not supported at this
            moment.
        output_config (google.cloud.datalabeling_v1beta1.types.OutputConfig):
            Required. Specify the output destination.
        user_email_address (str):
            Email of the user who started the export task
            and should be notified by email. If empty no
            notification will be sent.
    """

    name = proto.Field(proto.STRING, number=1,)
    annotated_dataset = proto.Field(proto.STRING, number=2,)
    filter = proto.Field(proto.STRING, number=3,)
    output_config = proto.Field(
        proto.MESSAGE, number=4, message=gcd_dataset.OutputConfig,
    )
    user_email_address = proto.Field(proto.STRING, number=5,)


class GetDataItemRequest(proto.Message):
    r"""Request message for GetDataItem.
    Attributes:
        name (str):
            Required. The name of the data item to get, format:
            projects/{project_id}/datasets/{dataset_id}/dataItems/{data_item_id}
    """

    name = proto.Field(proto.STRING, number=1,)


class ListDataItemsRequest(proto.Message):
    r"""Request message for ListDataItems.
    Attributes:
        parent (str):
            Required. Name of the dataset to list data items, format:
            projects/{project_id}/datasets/{dataset_id}
        filter (str):
            Optional. Filter is not supported at this
            moment.
        page_size (int):
            Optional. Requested page size. Server may
            return fewer results than requested. Default
            value is 100.
        page_token (str):
            Optional. A token identifying a page of results for the
            server to return. Typically obtained by
            [ListDataItemsResponse.next_page_token][google.cloud.datalabeling.v1beta1.ListDataItemsResponse.next_page_token]
            of the previous [DataLabelingService.ListDataItems] call.
            Return first page if empty.
    """

    parent = proto.Field(proto.STRING, number=1,)
    filter = proto.Field(proto.STRING, number=2,)
    page_size = proto.Field(proto.INT32, number=3,)
    page_token = proto.Field(proto.STRING, number=4,)


class ListDataItemsResponse(proto.Message):
    r"""Results of listing data items in a dataset.
    Attributes:
        data_items (Sequence[google.cloud.datalabeling_v1beta1.types.DataItem]):
            The list of data items to return.
        next_page_token (str):
            A token to retrieve next page of results.
    """

    @property
    def raw_page(self):
        return self

    data_items = proto.RepeatedField(
        proto.MESSAGE, number=1, message=gcd_dataset.DataItem,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetAnnotatedDatasetRequest(proto.Message):
    r"""Request message for GetAnnotatedDataset.
    Attributes:
        name (str):
            Required. Name of the annotated dataset to get, format:
            projects/{project_id}/datasets/{dataset_id}/annotatedDatasets/
            {annotated_dataset_id}
    """

    name = proto.Field(proto.STRING, number=1,)


class ListAnnotatedDatasetsRequest(proto.Message):
    r"""Request message for ListAnnotatedDatasets.
    Attributes:
        parent (str):
            Required. Name of the dataset to list annotated datasets,
            format: projects/{project_id}/datasets/{dataset_id}
        filter (str):
            Optional. Filter is not supported at this
            moment.
        page_size (int):
            Optional. Requested page size. Server may
            return fewer results than requested. Default
            value is 100.
        page_token (str):
            Optional. A token identifying a page of results for the
            server to return. Typically obtained by
            [ListAnnotatedDatasetsResponse.next_page_token][google.cloud.datalabeling.v1beta1.ListAnnotatedDatasetsResponse.next_page_token]
            of the previous [DataLabelingService.ListAnnotatedDatasets]
            call. Return first page if empty.
    """

    parent = proto.Field(proto.STRING, number=1,)
    filter = proto.Field(proto.STRING, number=2,)
    page_size = proto.Field(proto.INT32, number=3,)
    page_token = proto.Field(proto.STRING, number=4,)


class ListAnnotatedDatasetsResponse(proto.Message):
    r"""Results of listing annotated datasets for a dataset.
    Attributes:
        annotated_datasets (Sequence[google.cloud.datalabeling_v1beta1.types.AnnotatedDataset]):
            The list of annotated datasets to return.
        next_page_token (str):
            A token to retrieve next page of results.
    """

    @property
    def raw_page(self):
        return self

    annotated_datasets = proto.RepeatedField(
        proto.MESSAGE, number=1, message=gcd_dataset.AnnotatedDataset,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class DeleteAnnotatedDatasetRequest(proto.Message):
    r"""Request message for DeleteAnnotatedDataset.
    Attributes:
        name (str):
            Required. Name of the annotated dataset to delete, format:
            projects/{project_id}/datasets/{dataset_id}/annotatedDatasets/
            {annotated_dataset_id}
    """

    name = proto.Field(proto.STRING, number=1,)


class LabelImageRequest(proto.Message):
    r"""Request message for starting an image labeling task.
    Attributes:
        image_classification_config (google.cloud.datalabeling_v1beta1.types.ImageClassificationConfig):
            Configuration for image classification task. One of
            image_classification_config, bounding_poly_config,
            polyline_config and segmentation_config are required.
        bounding_poly_config (google.cloud.datalabeling_v1beta1.types.BoundingPolyConfig):
            Configuration for bounding box and bounding poly task. One
            of image_classification_config, bounding_poly_config,
            polyline_config and segmentation_config are required.
        polyline_config (google.cloud.datalabeling_v1beta1.types.PolylineConfig):
            Configuration for polyline task. One of
            image_classification_config, bounding_poly_config,
            polyline_config and segmentation_config are required.
        segmentation_config (google.cloud.datalabeling_v1beta1.types.SegmentationConfig):
            Configuration for segmentation task. One of
            image_classification_config, bounding_poly_config,
            polyline_config and segmentation_config are required.
        parent (str):
            Required. Name of the dataset to request labeling task,
            format: projects/{project_id}/datasets/{dataset_id}
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Required. Basic human annotation config.
        feature (google.cloud.datalabeling_v1beta1.types.LabelImageRequest.Feature):
            Required. The type of image labeling task.
    """

    class Feature(proto.Enum):
        r"""Image labeling task feature."""
        FEATURE_UNSPECIFIED = 0
        CLASSIFICATION = 1
        BOUNDING_BOX = 2
        ORIENTED_BOUNDING_BOX = 6
        BOUNDING_POLY = 3
        POLYLINE = 4
        SEGMENTATION = 5

    image_classification_config = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="request_config",
        message=human_annotation_config.ImageClassificationConfig,
    )
    bounding_poly_config = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="request_config",
        message=human_annotation_config.BoundingPolyConfig,
    )
    polyline_config = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="request_config",
        message=human_annotation_config.PolylineConfig,
    )
    segmentation_config = proto.Field(
        proto.MESSAGE,
        number=7,
        oneof="request_config",
        message=human_annotation_config.SegmentationConfig,
    )
    parent = proto.Field(proto.STRING, number=1,)
    basic_config = proto.Field(
        proto.MESSAGE, number=2, message=human_annotation_config.HumanAnnotationConfig,
    )
    feature = proto.Field(proto.ENUM, number=3, enum=Feature,)


class LabelVideoRequest(proto.Message):
    r"""Request message for LabelVideo.
    Attributes:
        video_classification_config (google.cloud.datalabeling_v1beta1.types.VideoClassificationConfig):
            Configuration for video classification task. One of
            video_classification_config, object_detection_config,
            object_tracking_config and event_config is required.
        object_detection_config (google.cloud.datalabeling_v1beta1.types.ObjectDetectionConfig):
            Configuration for video object detection task. One of
            video_classification_config, object_detection_config,
            object_tracking_config and event_config is required.
        object_tracking_config (google.cloud.datalabeling_v1beta1.types.ObjectTrackingConfig):
            Configuration for video object tracking task. One of
            video_classification_config, object_detection_config,
            object_tracking_config and event_config is required.
        event_config (google.cloud.datalabeling_v1beta1.types.EventConfig):
            Configuration for video event task. One of
            video_classification_config, object_detection_config,
            object_tracking_config and event_config is required.
        parent (str):
            Required. Name of the dataset to request labeling task,
            format: projects/{project_id}/datasets/{dataset_id}
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Required. Basic human annotation config.
        feature (google.cloud.datalabeling_v1beta1.types.LabelVideoRequest.Feature):
            Required. The type of video labeling task.
    """

    class Feature(proto.Enum):
        r"""Video labeling task feature."""
        FEATURE_UNSPECIFIED = 0
        CLASSIFICATION = 1
        OBJECT_DETECTION = 2
        OBJECT_TRACKING = 3
        EVENT = 4

    video_classification_config = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="request_config",
        message=human_annotation_config.VideoClassificationConfig,
    )
    object_detection_config = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="request_config",
        message=human_annotation_config.ObjectDetectionConfig,
    )
    object_tracking_config = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="request_config",
        message=human_annotation_config.ObjectTrackingConfig,
    )
    event_config = proto.Field(
        proto.MESSAGE,
        number=7,
        oneof="request_config",
        message=human_annotation_config.EventConfig,
    )
    parent = proto.Field(proto.STRING, number=1,)
    basic_config = proto.Field(
        proto.MESSAGE, number=2, message=human_annotation_config.HumanAnnotationConfig,
    )
    feature = proto.Field(proto.ENUM, number=3, enum=Feature,)


class LabelTextRequest(proto.Message):
    r"""Request message for LabelText.
    Attributes:
        text_classification_config (google.cloud.datalabeling_v1beta1.types.TextClassificationConfig):
            Configuration for text classification task. One of
            text_classification_config and text_entity_extraction_config
            is required.
        text_entity_extraction_config (google.cloud.datalabeling_v1beta1.types.TextEntityExtractionConfig):
            Configuration for entity extraction task. One of
            text_classification_config and text_entity_extraction_config
            is required.
        parent (str):
            Required. Name of the data set to request labeling task,
            format: projects/{project_id}/datasets/{dataset_id}
        basic_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Required. Basic human annotation config.
        feature (google.cloud.datalabeling_v1beta1.types.LabelTextRequest.Feature):
            Required. The type of text labeling task.
    """

    class Feature(proto.Enum):
        r"""Text labeling task feature."""
        FEATURE_UNSPECIFIED = 0
        TEXT_CLASSIFICATION = 1
        TEXT_ENTITY_EXTRACTION = 2

    text_classification_config = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="request_config",
        message=human_annotation_config.TextClassificationConfig,
    )
    text_entity_extraction_config = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="request_config",
        message=human_annotation_config.TextEntityExtractionConfig,
    )
    parent = proto.Field(proto.STRING, number=1,)
    basic_config = proto.Field(
        proto.MESSAGE, number=2, message=human_annotation_config.HumanAnnotationConfig,
    )
    feature = proto.Field(proto.ENUM, number=6, enum=Feature,)


class GetExampleRequest(proto.Message):
    r"""Request message for GetExample
    Attributes:
        name (str):
            Required. Name of example, format:
            projects/{project_id}/datasets/{dataset_id}/annotatedDatasets/
            {annotated_dataset_id}/examples/{example_id}
        filter (str):
            Optional. An expression for filtering Examples. Filter by
            annotation_spec.display_name is supported. Format
            "annotation_spec.display_name = {display_name}".
    """

    name = proto.Field(proto.STRING, number=1,)
    filter = proto.Field(proto.STRING, number=2,)


class ListExamplesRequest(proto.Message):
    r"""Request message for ListExamples.
    Attributes:
        parent (str):
            Required. Example resource parent.
        filter (str):
            Optional. An expression for filtering Examples. For
            annotated datasets that have annotation spec set, filter by
            annotation_spec.display_name is supported. Format
            "annotation_spec.display_name = {display_name}".
        page_size (int):
            Optional. Requested page size. Server may
            return fewer results than requested. Default
            value is 100.
        page_token (str):
            Optional. A token identifying a page of results for the
            server to return. Typically obtained by
            [ListExamplesResponse.next_page_token][google.cloud.datalabeling.v1beta1.ListExamplesResponse.next_page_token]
            of the previous [DataLabelingService.ListExamples] call.
            Return first page if empty.
    """

    parent = proto.Field(proto.STRING, number=1,)
    filter = proto.Field(proto.STRING, number=2,)
    page_size = proto.Field(proto.INT32, number=3,)
    page_token = proto.Field(proto.STRING, number=4,)


class ListExamplesResponse(proto.Message):
    r"""Results of listing Examples in and annotated dataset.
    Attributes:
        examples (Sequence[google.cloud.datalabeling_v1beta1.types.Example]):
            The list of examples to return.
        next_page_token (str):
            A token to retrieve next page of results.
    """

    @property
    def raw_page(self):
        return self

    examples = proto.RepeatedField(
        proto.MESSAGE, number=1, message=gcd_dataset.Example,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class CreateAnnotationSpecSetRequest(proto.Message):
    r"""Request message for CreateAnnotationSpecSet.
    Attributes:
        parent (str):
            Required. AnnotationSpecSet resource parent, format:
            projects/{project_id}
        annotation_spec_set (google.cloud.datalabeling_v1beta1.types.AnnotationSpecSet):
            Required. Annotation spec set to create. Annotation specs
            must be included. Only one annotation spec will be accepted
            for annotation specs with same display_name.
    """

    parent = proto.Field(proto.STRING, number=1,)
    annotation_spec_set = proto.Field(
        proto.MESSAGE, number=2, message=gcd_annotation_spec_set.AnnotationSpecSet,
    )


class GetAnnotationSpecSetRequest(proto.Message):
    r"""Request message for GetAnnotationSpecSet.
    Attributes:
        name (str):
            Required. AnnotationSpecSet resource name, format:
            projects/{project_id}/annotationSpecSets/{annotation_spec_set_id}
    """

    name = proto.Field(proto.STRING, number=1,)


class ListAnnotationSpecSetsRequest(proto.Message):
    r"""Request message for ListAnnotationSpecSets.
    Attributes:
        parent (str):
            Required. Parent of AnnotationSpecSet resource, format:
            projects/{project_id}
        filter (str):
            Optional. Filter is not supported at this
            moment.
        page_size (int):
            Optional. Requested page size. Server may
            return fewer results than requested. Default
            value is 100.
        page_token (str):
            Optional. A token identifying a page of results for the
            server to return. Typically obtained by
            [ListAnnotationSpecSetsResponse.next_page_token][google.cloud.datalabeling.v1beta1.ListAnnotationSpecSetsResponse.next_page_token]
            of the previous [DataLabelingService.ListAnnotationSpecSets]
            call. Return first page if empty.
    """

    parent = proto.Field(proto.STRING, number=1,)
    filter = proto.Field(proto.STRING, number=2,)
    page_size = proto.Field(proto.INT32, number=3,)
    page_token = proto.Field(proto.STRING, number=4,)


class ListAnnotationSpecSetsResponse(proto.Message):
    r"""Results of listing annotation spec set under a project.
    Attributes:
        annotation_spec_sets (Sequence[google.cloud.datalabeling_v1beta1.types.AnnotationSpecSet]):
            The list of annotation spec sets.
        next_page_token (str):
            A token to retrieve next page of results.
    """

    @property
    def raw_page(self):
        return self

    annotation_spec_sets = proto.RepeatedField(
        proto.MESSAGE, number=1, message=gcd_annotation_spec_set.AnnotationSpecSet,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class DeleteAnnotationSpecSetRequest(proto.Message):
    r"""Request message for DeleteAnnotationSpecSet.
    Attributes:
        name (str):
            Required. AnnotationSpec resource name, format:
            ``projects/{project_id}/annotationSpecSets/{annotation_spec_set_id}``.
    """

    name = proto.Field(proto.STRING, number=1,)


class CreateInstructionRequest(proto.Message):
    r"""Request message for CreateInstruction.
    Attributes:
        parent (str):
            Required. Instruction resource parent, format:
            projects/{project_id}
        instruction (google.cloud.datalabeling_v1beta1.types.Instruction):
            Required. Instruction of how to perform the
            labeling task.
    """

    parent = proto.Field(proto.STRING, number=1,)
    instruction = proto.Field(
        proto.MESSAGE, number=2, message=gcd_instruction.Instruction,
    )


class GetInstructionRequest(proto.Message):
    r"""Request message for GetInstruction.
    Attributes:
        name (str):
            Required. Instruction resource name, format:
            projects/{project_id}/instructions/{instruction_id}
    """

    name = proto.Field(proto.STRING, number=1,)


class DeleteInstructionRequest(proto.Message):
    r"""Request message for DeleteInstruction.
    Attributes:
        name (str):
            Required. Instruction resource name, format:
            projects/{project_id}/instructions/{instruction_id}
    """

    name = proto.Field(proto.STRING, number=1,)


class ListInstructionsRequest(proto.Message):
    r"""Request message for ListInstructions.
    Attributes:
        parent (str):
            Required. Instruction resource parent, format:
            projects/{project_id}
        filter (str):
            Optional. Filter is not supported at this
            moment.
        page_size (int):
            Optional. Requested page size. Server may
            return fewer results than requested. Default
            value is 100.
        page_token (str):
            Optional. A token identifying a page of results for the
            server to return. Typically obtained by
            [ListInstructionsResponse.next_page_token][google.cloud.datalabeling.v1beta1.ListInstructionsResponse.next_page_token]
            of the previous [DataLabelingService.ListInstructions] call.
            Return first page if empty.
    """

    parent = proto.Field(proto.STRING, number=1,)
    filter = proto.Field(proto.STRING, number=2,)
    page_size = proto.Field(proto.INT32, number=3,)
    page_token = proto.Field(proto.STRING, number=4,)


class ListInstructionsResponse(proto.Message):
    r"""Results of listing instructions under a project.
    Attributes:
        instructions (Sequence[google.cloud.datalabeling_v1beta1.types.Instruction]):
            The list of Instructions to return.
        next_page_token (str):
            A token to retrieve next page of results.
    """

    @property
    def raw_page(self):
        return self

    instructions = proto.RepeatedField(
        proto.MESSAGE, number=1, message=gcd_instruction.Instruction,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetEvaluationRequest(proto.Message):
    r"""Request message for GetEvaluation.
    Attributes:
        name (str):
            Required. Name of the evaluation. Format:

            "projects/{project_id}/datasets/{dataset_id}/evaluations/{evaluation_id}'
    """

    name = proto.Field(proto.STRING, number=1,)


class SearchEvaluationsRequest(proto.Message):
    r"""Request message for SearchEvaluation.
    Attributes:
        parent (str):
            Required. Evaluation search parent (project ID). Format:
            "projects/{project_id}".
        filter (str):
            Optional. To search evaluations, you can filter by the
            following:

            -  evaluation\_job.evaluation_job_id (the last part of
               [EvaluationJob.name][google.cloud.datalabeling.v1beta1.EvaluationJob.name])
            -  evaluation\_job.model_id (the {model_name} portion of
               [EvaluationJob.modelVersion][google.cloud.datalabeling.v1beta1.EvaluationJob.model_version])
            -  evaluation\_job.evaluation_job_run_time_start (Minimum
               threshold for the
               [evaluationJobRunTime][google.cloud.datalabeling.v1beta1.Evaluation.evaluation_job_run_time]
               that created the evaluation)
            -  evaluation\_job.evaluation_job_run_time_end (Maximum
               threshold for the
               [evaluationJobRunTime][google.cloud.datalabeling.v1beta1.Evaluation.evaluation_job_run_time]
               that created the evaluation)
            -  evaluation\_job.job_state
               ([EvaluationJob.state][google.cloud.datalabeling.v1beta1.EvaluationJob.state])
            -  annotation\_spec.display_name (the Evaluation contains a
               metric for the annotation spec with this
               [displayName][google.cloud.datalabeling.v1beta1.AnnotationSpec.display_name])

            To filter by multiple critiera, use the ``AND`` operator or
            the ``OR`` operator. The following examples shows a string
            that filters by several critiera:

            "evaluation\ *job.evaluation_job_id = {evaluation_job_id}
            AND evaluation*\ job.model_id = {model_name} AND
            evaluation\ *job.evaluation_job_run_time_start =
            {timestamp_1} AND
            evaluation*\ job.evaluation_job_run_time_end = {timestamp_2}
            AND annotation\_spec.display_name = {display_name}".
        page_size (int):
            Optional. Requested page size. Server may
            return fewer results than requested. Default
            value is 100.
        page_token (str):
            Optional. A token identifying a page of results for the
            server to return. Typically obtained by the
            [nextPageToken][google.cloud.datalabeling.v1beta1.SearchEvaluationsResponse.next_page_token]
            of the response to a previous search request.

            If you don't specify this field, the API call requests the
            first page of the search.
    """

    parent = proto.Field(proto.STRING, number=1,)
    filter = proto.Field(proto.STRING, number=2,)
    page_size = proto.Field(proto.INT32, number=3,)
    page_token = proto.Field(proto.STRING, number=4,)


class SearchEvaluationsResponse(proto.Message):
    r"""Results of searching evaluations.
    Attributes:
        evaluations (Sequence[google.cloud.datalabeling_v1beta1.types.Evaluation]):
            The list of evaluations matching the search.
        next_page_token (str):
            A token to retrieve next page of results.
    """

    @property
    def raw_page(self):
        return self

    evaluations = proto.RepeatedField(
        proto.MESSAGE, number=1, message=evaluation.Evaluation,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class SearchExampleComparisonsRequest(proto.Message):
    r"""Request message of SearchExampleComparisons.
    Attributes:
        parent (str):
            Required. Name of the
            [Evaluation][google.cloud.datalabeling.v1beta1.Evaluation]
            resource to search for example comparisons from. Format:

            "projects/{project_id}/datasets/{dataset_id}/evaluations/{evaluation_id}".
        page_size (int):
            Optional. Requested page size. Server may
            return fewer results than requested. Default
            value is 100.
        page_token (str):
            Optional. A token identifying a page of results for the
            server to return. Typically obtained by the
            [nextPageToken][SearchExampleComparisons.next_page_token] of
            the response to a previous search rquest.

            If you don't specify this field, the API call requests the
            first page of the search.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class SearchExampleComparisonsResponse(proto.Message):
    r"""Results of searching example comparisons.
    Attributes:
        example_comparisons (Sequence[google.cloud.datalabeling_v1beta1.types.SearchExampleComparisonsResponse.ExampleComparison]):
            A list of example comparisons matching the
            search criteria.
        next_page_token (str):
            A token to retrieve next page of results.
    """

    class ExampleComparison(proto.Message):
        r"""Example comparisons comparing ground truth output and
        predictions for a specific input.

        Attributes:
            ground_truth_example (google.cloud.datalabeling_v1beta1.types.Example):
                The ground truth output for the input.
            model_created_examples (Sequence[google.cloud.datalabeling_v1beta1.types.Example]):
                Predictions by the model for the input.
        """

        ground_truth_example = proto.Field(
            proto.MESSAGE, number=1, message=gcd_dataset.Example,
        )
        model_created_examples = proto.RepeatedField(
            proto.MESSAGE, number=2, message=gcd_dataset.Example,
        )

    @property
    def raw_page(self):
        return self

    example_comparisons = proto.RepeatedField(
        proto.MESSAGE, number=1, message=ExampleComparison,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


class CreateEvaluationJobRequest(proto.Message):
    r"""Request message for CreateEvaluationJob.
    Attributes:
        parent (str):
            Required. Evaluation job resource parent. Format:
            "projects/{project_id}".
        job (google.cloud.datalabeling_v1beta1.types.EvaluationJob):
            Required. The evaluation job to create.
    """

    parent = proto.Field(proto.STRING, number=1,)
    job = proto.Field(
        proto.MESSAGE, number=2, message=gcd_evaluation_job.EvaluationJob,
    )


class UpdateEvaluationJobRequest(proto.Message):
    r"""Request message for UpdateEvaluationJob.
    Attributes:
        evaluation_job (google.cloud.datalabeling_v1beta1.types.EvaluationJob):
            Required. Evaluation job that is going to be
            updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Optional. Mask for which fields to update. You can only
            provide the following fields:

            -  ``evaluationJobConfig.humanAnnotationConfig.instruction``
            -  ``evaluationJobConfig.exampleCount``
            -  ``evaluationJobConfig.exampleSamplePercentage``

            You can provide more than one of these fields by separating
            them with commas.
    """

    evaluation_job = proto.Field(
        proto.MESSAGE, number=1, message=gcd_evaluation_job.EvaluationJob,
    )
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class GetEvaluationJobRequest(proto.Message):
    r"""Request message for GetEvaluationJob.
    Attributes:
        name (str):
            Required. Name of the evaluation job. Format:

            "projects/{project_id}/evaluationJobs/{evaluation_job_id}".
    """

    name = proto.Field(proto.STRING, number=1,)


class PauseEvaluationJobRequest(proto.Message):
    r"""Request message for PauseEvaluationJob.
    Attributes:
        name (str):
            Required. Name of the evaluation job that is going to be
            paused. Format:

            "projects/{project_id}/evaluationJobs/{evaluation_job_id}".
    """

    name = proto.Field(proto.STRING, number=1,)


class ResumeEvaluationJobRequest(proto.Message):
    r"""Request message ResumeEvaluationJob.
    Attributes:
        name (str):
            Required. Name of the evaluation job that is going to be
            resumed. Format:

            "projects/{project_id}/evaluationJobs/{evaluation_job_id}".
    """

    name = proto.Field(proto.STRING, number=1,)


class DeleteEvaluationJobRequest(proto.Message):
    r"""Request message DeleteEvaluationJob.
    Attributes:
        name (str):
            Required. Name of the evaluation job that is going to be
            deleted. Format:

            "projects/{project_id}/evaluationJobs/{evaluation_job_id}".
    """

    name = proto.Field(proto.STRING, number=1,)


class ListEvaluationJobsRequest(proto.Message):
    r"""Request message for ListEvaluationJobs.
    Attributes:
        parent (str):
            Required. Evaluation job resource parent. Format:
            "projects/{project_id}".
        filter (str):
            Optional. You can filter the jobs to list by model_id (also
            known as model_name, as described in
            [EvaluationJob.modelVersion][google.cloud.datalabeling.v1beta1.EvaluationJob.model_version])
            or by evaluation job state (as described in
            [EvaluationJob.state][google.cloud.datalabeling.v1beta1.EvaluationJob.state]).
            To filter by both criteria, use the ``AND`` operator or the
            ``OR`` operator. For example, you can use the following
            string for your filter: "evaluation\ *job.model_id =
            {model_name} AND evaluation*\ job.state =
            {evaluation_job_state}".
        page_size (int):
            Optional. Requested page size. Server may
            return fewer results than requested. Default
            value is 100.
        page_token (str):
            Optional. A token identifying a page of results for the
            server to return. Typically obtained by the
            [nextPageToken][google.cloud.datalabeling.v1beta1.ListEvaluationJobsResponse.next_page_token]
            in the response to the previous request. The request returns
            the first page if this is empty.
    """

    parent = proto.Field(proto.STRING, number=1,)
    filter = proto.Field(proto.STRING, number=2,)
    page_size = proto.Field(proto.INT32, number=3,)
    page_token = proto.Field(proto.STRING, number=4,)


class ListEvaluationJobsResponse(proto.Message):
    r"""Results for listing evaluation jobs.
    Attributes:
        evaluation_jobs (Sequence[google.cloud.datalabeling_v1beta1.types.EvaluationJob]):
            The list of evaluation jobs to return.
        next_page_token (str):
            A token to retrieve next page of results.
    """

    @property
    def raw_page(self):
        return self

    evaluation_jobs = proto.RepeatedField(
        proto.MESSAGE, number=1, message=gcd_evaluation_job.EvaluationJob,
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union

from google.api_core import gapic_v1  # type: ignore
from google.api_core import grpc_helpers_async  # type: ignore
from google.api_core import operations_v1  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.auth.transport.grpc import SslCredentials  # type: ignore
import packaging.version

import grpc  # type: ignore
from grpc.experimental import aio  # type: ignore

from google.cloud.datalabeling_v1beta1.types import annotation_spec_set
from google.cloud.datalabeling_v1beta1.types import (
    annotation_spec_set as gcd_annotation_spec_set,
)
from google.cloud.datalabeling_v1beta1.types import data_labeling_service
from google.cloud.datalabeling_v1beta1.types import dataset
from google.cloud.datalabeling_v1beta1.types import dataset as gcd_dataset
from google.cloud.datalabeling_v1beta1.types import evaluation
from google.cloud.datalabeling_v1beta1.types import evaluation_job
from google.cloud.datalabeling_v1beta1.types import evaluation_job as gcd_evaluation_job
from google.cloud.datalabeling_v1beta1.types import instruction
from google.longrunning import operations_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore
from .base import DataLabelingServiceTransport, DEFAULT_CLIENT_INFO
from .grpc import DataLabelingServiceGrpcTransport


class DataLabelingServiceGrpcAsyncIOTransport(DataLabelingServiceTransport):
    """gRPC AsyncIO backend transport for DataLabelingService.

    Service for the AI Platform Data Labeling API.

    This class defines the same methods as the primary client, so the
    primary client can load the underlying transport implementation
    and call it.

    It sends protocol buffers over the wire using gRPC (which is built on
    top of HTTP/2); the ``grpcio`` package must be installed.
    """

    _grpc_channel: aio.Channel
    _stubs: Dict[str, Callable] = {}

    @classmethod
    def create_channel(
        cls,
        host: str = "datalabeling.googleapis.com",
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        **kwargs,
    ) -> aio.Channel:
        """Create and return a gRPC AsyncIO channel object.
        Args:
            host (Optional[str]): The host for the channel to use.
            credentials (Optional[~.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if ``channel`` is provided.
            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                service. These are only used when credentials are not specified and
                are passed to :func:`google.auth.default`.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            kwargs (Optional[dict]): Keyword arguments, which are passed to the
                channel creation.
        Returns:
            aio.Channel: A gRPC AsyncIO channel object.
        """

        return grpc_helpers_async.create_channel(
            host,
            credentials=credentials,
            credentials_file=credentials_file,
            quota_project_id=quota_project_id,
            default_scopes=cls.AUTH_SCOPES,
            scopes=scopes,
            default_host=cls.DEFAULT_HOST,
            **kwargs,
        )

    def __init__(
        self,
        *,
        host: str = "datalabeling.googleapis.com",
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        channel: aio.Channel = None,
        api_mtls_endpoint: str = None,
        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
        ssl_channel_credentials: grpc.ChannelCredentials = None,
        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
        quota_project_id=None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is ignored if ``channel`` is provided.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if ``channel`` is provided.
            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                service. These are only used when credentials are not specified and
                are passed to :func:`google.auth.default`.
            channel (Optional[aio.Channel]): A ``Channel`` instance through
                which to make calls.
            api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                If provided, it overrides the ``host`` argument and tries to create
                a mutual TLS channel with client SSL credentials from
                ``client_cert_source`` or application default SSL credentials.
            client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                Deprecated. A callback to provide client SSL certificate bytes and
                private key bytes, both in PEM format. It is ignored if
                ``api_mtls_endpoint`` is None.
            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
                for the grpc channel. It is ignored if ``channel`` is provided.
            client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                A callback to provide client certificate bytes and private key bytes,
                both in PEM format. It is used to configure a mutual TLS channel. It is
                ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
              creation failed for any reason.
          google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
              and ``credentials_file`` are passed.
        """
        self._grpc_channel = None
        self._ssl_channel_credentials = ssl_channel_credentials
        self._stubs: Dict[str, Callable] = {}
        self._operations_client = None

        if api_mtls_endpoint:
            warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
        if client_cert_source:
            warnings.warn("client_cert_source is deprecated", DeprecationWarning)

        if channel:
            # Ignore credentials if a channel was passed.
            credentials = False
            # If a channel was explicitly provided, set it.
            self._grpc_channel = channel
            self._ssl_channel_credentials = None
        else:
            if api_mtls_endpoint:
                host = api_mtls_endpoint

                # Create SSL credentials with client_cert_source or application
                # default SSL credentials.
                if client_cert_source:
                    cert, key = client_cert_source()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )
                else:
                    self._ssl_channel_credentials = SslCredentials().ssl_credentials

            else:
                if client_cert_source_for_mtls and not ssl_channel_credentials:
                    cert, key = client_cert_source_for_mtls()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )

        # The base transport sets the host, credentials and scopes
        super().__init__(
            host=host,
            credentials=credentials,
            credentials_file=credentials_file,
            scopes=scopes,
            quota_project_id=quota_project_id,
            client_info=client_info,
            always_use_jwt_access=always_use_jwt_access,
        )

        if not self._grpc_channel:
            self._grpc_channel = type(self).create_channel(
                self._host,
                credentials=self._credentials,
                credentials_file=credentials_file,
                scopes=self._scopes,
                ssl_credentials=self._ssl_channel_credentials,
                quota_project_id=quota_project_id,
                options=[
                    ("grpc.max_send_message_length", -1),
                    ("grpc.max_receive_message_length", -1),
                ],
            )

        # Wrap messages. This must be done after self._grpc_channel exists
        self._prep_wrapped_messages(client_info)

    @property
    def grpc_channel(self) -> aio.Channel:
        """Create the channel designed to connect to this service.

        This property caches on the instance; repeated calls return
        the same channel.
        """
        # Return the channel from cache.
        return self._grpc_channel

    @property
    def operations_client(self) -> operations_v1.OperationsAsyncClient:
        """Create the client designed to process long-running operations.

        This property caches on the instance; repeated calls return the same
        client.
        """
        # Sanity check: Only create a new client if we do not already have one.
        if self._operations_client is None:
            self._operations_client = operations_v1.OperationsAsyncClient(
                self.grpc_channel
            )

        # Return the client from cache.
        return self._operations_client

    @property
    def create_dataset(
        self,
    ) -> Callable[
        [data_labeling_service.CreateDatasetRequest], Awaitable[gcd_dataset.Dataset]
    ]:
        r"""Return a callable for the create dataset method over gRPC.

        Creates dataset. If success return a Dataset
        resource.

        Returns:
            Callable[[~.CreateDatasetRequest],
                    Awaitable[~.Dataset]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_dataset" not in self._stubs:
            self._stubs["create_dataset"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/CreateDataset",
                request_serializer=data_labeling_service.CreateDatasetRequest.serialize,
                response_deserializer=gcd_dataset.Dataset.deserialize,
            )
        return self._stubs["create_dataset"]

    @property
    def get_dataset(
        self,
    ) -> Callable[
        [data_labeling_service.GetDatasetRequest], Awaitable[dataset.Dataset]
    ]:
        r"""Return a callable for the get dataset method over gRPC.

        Gets dataset by resource name.

        Returns:
            Callable[[~.GetDatasetRequest],
                    Awaitable[~.Dataset]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_dataset" not in self._stubs:
            self._stubs["get_dataset"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/GetDataset",
                request_serializer=data_labeling_service.GetDatasetRequest.serialize,
                response_deserializer=dataset.Dataset.deserialize,
            )
        return self._stubs["get_dataset"]

    @property
    def list_datasets(
        self,
    ) -> Callable[
        [data_labeling_service.ListDatasetsRequest],
        Awaitable[data_labeling_service.ListDatasetsResponse],
    ]:
        r"""Return a callable for the list datasets method over gRPC.

        Lists datasets under a project. Pagination is
        supported.

        Returns:
            Callable[[~.ListDatasetsRequest],
                    Awaitable[~.ListDatasetsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_datasets" not in self._stubs:
            self._stubs["list_datasets"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/ListDatasets",
                request_serializer=data_labeling_service.ListDatasetsRequest.serialize,
                response_deserializer=data_labeling_service.ListDatasetsResponse.deserialize,
            )
        return self._stubs["list_datasets"]

    @property
    def delete_dataset(
        self,
    ) -> Callable[
        [data_labeling_service.DeleteDatasetRequest], Awaitable[empty_pb2.Empty]
    ]:
        r"""Return a callable for the delete dataset method over gRPC.

        Deletes a dataset by resource name.

        Returns:
            Callable[[~.DeleteDatasetRequest],
                    Awaitable[~.Empty]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_dataset" not in self._stubs:
            self._stubs["delete_dataset"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/DeleteDataset",
                request_serializer=data_labeling_service.DeleteDatasetRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_dataset"]

    @property
    def import_data(
        self,
    ) -> Callable[
        [data_labeling_service.ImportDataRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the import data method over gRPC.

        Imports data into dataset based on source locations
        defined in request. It can be called multiple times for
        the same dataset. Each dataset can only have one long
        running operation running on it. For example, no
        labeling task (also long running operation) can be
        started while importing is still ongoing. Vice versa.

        Returns:
            Callable[[~.ImportDataRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "import_data" not in self._stubs:
            self._stubs["import_data"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/ImportData",
                request_serializer=data_labeling_service.ImportDataRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["import_data"]

    @property
    def export_data(
        self,
    ) -> Callable[
        [data_labeling_service.ExportDataRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the export data method over gRPC.

        Exports data and annotations from dataset.

        Returns:
            Callable[[~.ExportDataRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "export_data" not in self._stubs:
            self._stubs["export_data"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/ExportData",
                request_serializer=data_labeling_service.ExportDataRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["export_data"]

    @property
    def get_data_item(
        self,
    ) -> Callable[
        [data_labeling_service.GetDataItemRequest], Awaitable[dataset.DataItem]
    ]:
        r"""Return a callable for the get data item method over gRPC.

        Gets a data item in a dataset by resource name. This
        API can be called after data are imported into dataset.

        Returns:
            Callable[[~.GetDataItemRequest],
                    Awaitable[~.DataItem]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_data_item" not in self._stubs:
            self._stubs["get_data_item"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/GetDataItem",
                request_serializer=data_labeling_service.GetDataItemRequest.serialize,
                response_deserializer=dataset.DataItem.deserialize,
            )
        return self._stubs["get_data_item"]

    @property
    def list_data_items(
        self,
    ) -> Callable[
        [data_labeling_service.ListDataItemsRequest],
        Awaitable[data_labeling_service.ListDataItemsResponse],
    ]:
        r"""Return a callable for the list data items method over gRPC.

        Lists data items in a dataset. This API can be called
        after data are imported into dataset. Pagination is
        supported.

        Returns:
            Callable[[~.ListDataItemsRequest],
                    Awaitable[~.ListDataItemsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_data_items" not in self._stubs:
            self._stubs["list_data_items"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/ListDataItems",
                request_serializer=data_labeling_service.ListDataItemsRequest.serialize,
                response_deserializer=data_labeling_service.ListDataItemsResponse.deserialize,
            )
        return self._stubs["list_data_items"]

    @property
    def get_annotated_dataset(
        self,
    ) -> Callable[
        [data_labeling_service.GetAnnotatedDatasetRequest],
        Awaitable[dataset.AnnotatedDataset],
    ]:
        r"""Return a callable for the get annotated dataset method over gRPC.

        Gets an annotated dataset by resource name.

        Returns:
            Callable[[~.GetAnnotatedDatasetRequest],
                    Awaitable[~.AnnotatedDataset]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_annotated_dataset" not in self._stubs:
            self._stubs["get_annotated_dataset"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/GetAnnotatedDataset",
                request_serializer=data_labeling_service.GetAnnotatedDatasetRequest.serialize,
                response_deserializer=dataset.AnnotatedDataset.deserialize,
            )
        return self._stubs["get_annotated_dataset"]

    @property
    def list_annotated_datasets(
        self,
    ) -> Callable[
        [data_labeling_service.ListAnnotatedDatasetsRequest],
        Awaitable[data_labeling_service.ListAnnotatedDatasetsResponse],
    ]:
        r"""Return a callable for the list annotated datasets method over gRPC.

        Lists annotated datasets for a dataset. Pagination is
        supported.

        Returns:
            Callable[[~.ListAnnotatedDatasetsRequest],
                    Awaitable[~.ListAnnotatedDatasetsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_annotated_datasets" not in self._stubs:
            self._stubs["list_annotated_datasets"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/ListAnnotatedDatasets",
                request_serializer=data_labeling_service.ListAnnotatedDatasetsRequest.serialize,
                response_deserializer=data_labeling_service.ListAnnotatedDatasetsResponse.deserialize,
            )
        return self._stubs["list_annotated_datasets"]

    @property
    def delete_annotated_dataset(
        self,
    ) -> Callable[
        [data_labeling_service.DeleteAnnotatedDatasetRequest],
        Awaitable[empty_pb2.Empty],
    ]:
        r"""Return a callable for the delete annotated dataset method over gRPC.

        Deletes an annotated dataset by resource name.

        Returns:
            Callable[[~.DeleteAnnotatedDatasetRequest],
                    Awaitable[~.Empty]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_annotated_dataset" not in self._stubs:
            self._stubs["delete_annotated_dataset"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/DeleteAnnotatedDataset",
                request_serializer=data_labeling_service.DeleteAnnotatedDatasetRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_annotated_dataset"]

    @property
    def label_image(
        self,
    ) -> Callable[
        [data_labeling_service.LabelImageRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the label image method over gRPC.

        Starts a labeling task for image. The type of image
        labeling task is configured by feature in the request.

        Returns:
            Callable[[~.LabelImageRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "label_image" not in self._stubs:
            self._stubs["label_image"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/LabelImage",
                request_serializer=data_labeling_service.LabelImageRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["label_image"]

    @property
    def label_video(
        self,
    ) -> Callable[
        [data_labeling_service.LabelVideoRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the label video method over gRPC.

        Starts a labeling task for video. The type of video
        labeling task is configured by feature in the request.

        Returns:
            Callable[[~.LabelVideoRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "label_video" not in self._stubs:
            self._stubs["label_video"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/LabelVideo",
                request_serializer=data_labeling_service.LabelVideoRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["label_video"]

    @property
    def label_text(
        self,
    ) -> Callable[
        [data_labeling_service.LabelTextRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the label text method over gRPC.

        Starts a labeling task for text. The type of text
        labeling task is configured by feature in the request.

        Returns:
            Callable[[~.LabelTextRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "label_text" not in self._stubs:
            self._stubs["label_text"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/LabelText",
                request_serializer=data_labeling_service.LabelTextRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["label_text"]

    @property
    def get_example(
        self,
    ) -> Callable[
        [data_labeling_service.GetExampleRequest], Awaitable[dataset.Example]
    ]:
        r"""Return a callable for the get example method over gRPC.

        Gets an example by resource name, including both data
        and annotation.

        Returns:
            Callable[[~.GetExampleRequest],
                    Awaitable[~.Example]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_example" not in self._stubs:
            self._stubs["get_example"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/GetExample",
                request_serializer=data_labeling_service.GetExampleRequest.serialize,
                response_deserializer=dataset.Example.deserialize,
            )
        return self._stubs["get_example"]

    @property
    def list_examples(
        self,
    ) -> Callable[
        [data_labeling_service.ListExamplesRequest],
        Awaitable[data_labeling_service.ListExamplesResponse],
    ]:
        r"""Return a callable for the list examples method over gRPC.

        Lists examples in an annotated dataset. Pagination is
        supported.

        Returns:
            Callable[[~.ListExamplesRequest],
                    Awaitable[~.ListExamplesResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_examples" not in self._stubs:
            self._stubs["list_examples"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/ListExamples",
                request_serializer=data_labeling_service.ListExamplesRequest.serialize,
                response_deserializer=data_labeling_service.ListExamplesResponse.deserialize,
            )
        return self._stubs["list_examples"]

    @property
    def create_annotation_spec_set(
        self,
    ) -> Callable[
        [data_labeling_service.CreateAnnotationSpecSetRequest],
        Awaitable[gcd_annotation_spec_set.AnnotationSpecSet],
    ]:
        r"""Return a callable for the create annotation spec set method over gRPC.

        Creates an annotation spec set by providing a set of
        labels.

        Returns:
            Callable[[~.CreateAnnotationSpecSetRequest],
                    Awaitable[~.AnnotationSpecSet]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_annotation_spec_set" not in self._stubs:
            self._stubs["create_annotation_spec_set"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/CreateAnnotationSpecSet",
                request_serializer=data_labeling_service.CreateAnnotationSpecSetRequest.serialize,
                response_deserializer=gcd_annotation_spec_set.AnnotationSpecSet.deserialize,
            )
        return self._stubs["create_annotation_spec_set"]

    @property
    def get_annotation_spec_set(
        self,
    ) -> Callable[
        [data_labeling_service.GetAnnotationSpecSetRequest],
        Awaitable[annotation_spec_set.AnnotationSpecSet],
    ]:
        r"""Return a callable for the get annotation spec set method over gRPC.

        Gets an annotation spec set by resource name.

        Returns:
            Callable[[~.GetAnnotationSpecSetRequest],
                    Awaitable[~.AnnotationSpecSet]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_annotation_spec_set" not in self._stubs:
            self._stubs["get_annotation_spec_set"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/GetAnnotationSpecSet",
                request_serializer=data_labeling_service.GetAnnotationSpecSetRequest.serialize,
                response_deserializer=annotation_spec_set.AnnotationSpecSet.deserialize,
            )
        return self._stubs["get_annotation_spec_set"]

    @property
    def list_annotation_spec_sets(
        self,
    ) -> Callable[
        [data_labeling_service.ListAnnotationSpecSetsRequest],
        Awaitable[data_labeling_service.ListAnnotationSpecSetsResponse],
    ]:
        r"""Return a callable for the list annotation spec sets method over gRPC.

        Lists annotation spec sets for a project. Pagination
        is supported.

        Returns:
            Callable[[~.ListAnnotationSpecSetsRequest],
                    Awaitable[~.ListAnnotationSpecSetsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_annotation_spec_sets" not in self._stubs:
            self._stubs["list_annotation_spec_sets"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/ListAnnotationSpecSets",
                request_serializer=data_labeling_service.ListAnnotationSpecSetsRequest.serialize,
                response_deserializer=data_labeling_service.ListAnnotationSpecSetsResponse.deserialize,
            )
        return self._stubs["list_annotation_spec_sets"]

    @property
    def delete_annotation_spec_set(
        self,
    ) -> Callable[
        [data_labeling_service.DeleteAnnotationSpecSetRequest],
        Awaitable[empty_pb2.Empty],
    ]:
        r"""Return a callable for the delete annotation spec set method over gRPC.

        Deletes an annotation spec set by resource name.

        Returns:
            Callable[[~.DeleteAnnotationSpecSetRequest],
                    Awaitable[~.Empty]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_annotation_spec_set" not in self._stubs:
            self._stubs["delete_annotation_spec_set"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/DeleteAnnotationSpecSet",
                request_serializer=data_labeling_service.DeleteAnnotationSpecSetRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_annotation_spec_set"]

    @property
    def create_instruction(
        self,
    ) -> Callable[
        [data_labeling_service.CreateInstructionRequest],
        Awaitable[operations_pb2.Operation],
    ]:
        r"""Return a callable for the create instruction method over gRPC.

        Creates an instruction for how data should be
        labeled.

        Returns:
            Callable[[~.CreateInstructionRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_instruction" not in self._stubs:
            self._stubs["create_instruction"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/CreateInstruction",
                request_serializer=data_labeling_service.CreateInstructionRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_instruction"]

    @property
    def get_instruction(
        self,
    ) -> Callable[
        [data_labeling_service.GetInstructionRequest],
        Awaitable[instruction.Instruction],
    ]:
        r"""Return a callable for the get instruction method over gRPC.

        Gets an instruction by resource name.

        Returns:
            Callable[[~.GetInstructionRequest],
                    Awaitable[~.Instruction]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_instruction" not in self._stubs:
            self._stubs["get_instruction"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/GetInstruction",
                request_serializer=data_labeling_service.GetInstructionRequest.serialize,
                response_deserializer=instruction.Instruction.deserialize,
            )
        return self._stubs["get_instruction"]

    @property
    def list_instructions(
        self,
    ) -> Callable[
        [data_labeling_service.ListInstructionsRequest],
        Awaitable[data_labeling_service.ListInstructionsResponse],
    ]:
        r"""Return a callable for the list instructions method over gRPC.

        Lists instructions for a project. Pagination is
        supported.

        Returns:
            Callable[[~.ListInstructionsRequest],
                    Awaitable[~.ListInstructionsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_instructions" not in self._stubs:
            self._stubs["list_instructions"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/ListInstructions",
                request_serializer=data_labeling_service.ListInstructionsRequest.serialize,
                response_deserializer=data_labeling_service.ListInstructionsResponse.deserialize,
            )
        return self._stubs["list_instructions"]

    @property
    def delete_instruction(
        self,
    ) -> Callable[
        [data_labeling_service.DeleteInstructionRequest], Awaitable[empty_pb2.Empty]
    ]:
        r"""Return a callable for the delete instruction method over gRPC.

        Deletes an instruction object by resource name.

        Returns:
            Callable[[~.DeleteInstructionRequest],
                    Awaitable[~.Empty]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_instruction" not in self._stubs:
            self._stubs["delete_instruction"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/DeleteInstruction",
                request_serializer=data_labeling_service.DeleteInstructionRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_instruction"]

    @property
    def get_evaluation(
        self,
    ) -> Callable[
        [data_labeling_service.GetEvaluationRequest], Awaitable[evaluation.Evaluation]
    ]:
        r"""Return a callable for the get evaluation method over gRPC.

        Gets an evaluation by resource name (to search, use
        [projects.evaluations.search][google.cloud.datalabeling.v1beta1.DataLabelingService.SearchEvaluations]).

        Returns:
            Callable[[~.GetEvaluationRequest],
                    Awaitable[~.Evaluation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_evaluation" not in self._stubs:
            self._stubs["get_evaluation"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/GetEvaluation",
                request_serializer=data_labeling_service.GetEvaluationRequest.serialize,
                response_deserializer=evaluation.Evaluation.deserialize,
            )
        return self._stubs["get_evaluation"]

    @property
    def search_evaluations(
        self,
    ) -> Callable[
        [data_labeling_service.SearchEvaluationsRequest],
        Awaitable[data_labeling_service.SearchEvaluationsResponse],
    ]:
        r"""Return a callable for the search evaluations method over gRPC.

        Searches
        [evaluations][google.cloud.datalabeling.v1beta1.Evaluation]
        within a project.

        Returns:
            Callable[[~.SearchEvaluationsRequest],
                    Awaitable[~.SearchEvaluationsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "search_evaluations" not in self._stubs:
            self._stubs["search_evaluations"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/SearchEvaluations",
                request_serializer=data_labeling_service.SearchEvaluationsRequest.serialize,
                response_deserializer=data_labeling_service.SearchEvaluationsResponse.deserialize,
            )
        return self._stubs["search_evaluations"]

    @property
    def search_example_comparisons(
        self,
    ) -> Callable[
        [data_labeling_service.SearchExampleComparisonsRequest],
        Awaitable[data_labeling_service.SearchExampleComparisonsResponse],
    ]:
        r"""Return a callable for the search example comparisons method over gRPC.

        Searches example comparisons from an evaluation. The
        return format is a list of example comparisons that show
        ground truth and prediction(s) for a single input.
        Search by providing an evaluation ID.

        Returns:
            Callable[[~.SearchExampleComparisonsRequest],
                    Awaitable[~.SearchExampleComparisonsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "search_example_comparisons" not in self._stubs:
            self._stubs["search_example_comparisons"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/SearchExampleComparisons",
                request_serializer=data_labeling_service.SearchExampleComparisonsRequest.serialize,
                response_deserializer=data_labeling_service.SearchExampleComparisonsResponse.deserialize,
            )
        return self._stubs["search_example_comparisons"]

    @property
    def create_evaluation_job(
        self,
    ) -> Callable[
        [data_labeling_service.CreateEvaluationJobRequest],
        Awaitable[evaluation_job.EvaluationJob],
    ]:
        r"""Return a callable for the create evaluation job method over gRPC.

        Creates an evaluation job.

        Returns:
            Callable[[~.CreateEvaluationJobRequest],
                    Awaitable[~.EvaluationJob]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_evaluation_job" not in self._stubs:
            self._stubs["create_evaluation_job"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/CreateEvaluationJob",
                request_serializer=data_labeling_service.CreateEvaluationJobRequest.serialize,
                response_deserializer=evaluation_job.EvaluationJob.deserialize,
            )
        return self._stubs["create_evaluation_job"]

    @property
    def update_evaluation_job(
        self,
    ) -> Callable[
        [data_labeling_service.UpdateEvaluationJobRequest],
        Awaitable[gcd_evaluation_job.EvaluationJob],
    ]:
        r"""Return a callable for the update evaluation job method over gRPC.

        Updates an evaluation job. You can only update certain fields of
        the job's
        [EvaluationJobConfig][google.cloud.datalabeling.v1beta1.EvaluationJobConfig]:
        ``humanAnnotationConfig.instruction``, ``exampleCount``, and
        ``exampleSamplePercentage``.

        If you want to change any other aspect of the evaluation job,
        you must delete the job and create a new one.

        Returns:
            Callable[[~.UpdateEvaluationJobRequest],
                    Awaitable[~.EvaluationJob]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_evaluation_job" not in self._stubs:
            self._stubs["update_evaluation_job"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/UpdateEvaluationJob",
                request_serializer=data_labeling_service.UpdateEvaluationJobRequest.serialize,
                response_deserializer=gcd_evaluation_job.EvaluationJob.deserialize,
            )
        return self._stubs["update_evaluation_job"]

    @property
    def get_evaluation_job(
        self,
    ) -> Callable[
        [data_labeling_service.GetEvaluationJobRequest],
        Awaitable[evaluation_job.EvaluationJob],
    ]:
        r"""Return a callable for the get evaluation job method over gRPC.

        Gets an evaluation job by resource name.

        Returns:
            Callable[[~.GetEvaluationJobRequest],
                    Awaitable[~.EvaluationJob]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_evaluation_job" not in self._stubs:
            self._stubs["get_evaluation_job"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/GetEvaluationJob",
                request_serializer=data_labeling_service.GetEvaluationJobRequest.serialize,
                response_deserializer=evaluation_job.EvaluationJob.deserialize,
            )
        return self._stubs["get_evaluation_job"]

    @property
    def pause_evaluation_job(
        self,
    ) -> Callable[
        [data_labeling_service.PauseEvaluationJobRequest], Awaitable[empty_pb2.Empty]
    ]:
        r"""Return a callable for the pause evaluation job method over gRPC.

        Pauses an evaluation job. Pausing an evaluation job that is
        already in a ``PAUSED`` state is a no-op.

        Returns:
            Callable[[~.PauseEvaluationJobRequest],
                    Awaitable[~.Empty]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "pause_evaluation_job" not in self._stubs:
            self._stubs["pause_evaluation_job"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/PauseEvaluationJob",
                request_serializer=data_labeling_service.PauseEvaluationJobRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["pause_evaluation_job"]

    @property
    def resume_evaluation_job(
        self,
    ) -> Callable[
        [data_labeling_service.ResumeEvaluationJobRequest], Awaitable[empty_pb2.Empty]
    ]:
        r"""Return a callable for the resume evaluation job method over gRPC.

        Resumes a paused evaluation job. A deleted evaluation
        job can't be resumed. Resuming a running or scheduled
        evaluation job is a no-op.

        Returns:
            Callable[[~.ResumeEvaluationJobRequest],
                    Awaitable[~.Empty]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "resume_evaluation_job" not in self._stubs:
            self._stubs["resume_evaluation_job"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/ResumeEvaluationJob",
                request_serializer=data_labeling_service.ResumeEvaluationJobRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["resume_evaluation_job"]

    @property
    def delete_evaluation_job(
        self,
    ) -> Callable[
        [data_labeling_service.DeleteEvaluationJobRequest], Awaitable[empty_pb2.Empty]
    ]:
        r"""Return a callable for the delete evaluation job method over gRPC.

        Stops and deletes an evaluation job.

        Returns:
            Callable[[~.DeleteEvaluationJobRequest],
                    Awaitable[~.Empty]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_evaluation_job" not in self._stubs:
            self._stubs["delete_evaluation_job"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/DeleteEvaluationJob",
                request_serializer=data_labeling_service.DeleteEvaluationJobRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_evaluation_job"]

    @property
    def list_evaluation_jobs(
        self,
    ) -> Callable[
        [data_labeling_service.ListEvaluationJobsRequest],
        Awaitable[data_labeling_service.ListEvaluationJobsResponse],
    ]:
        r"""Return a callable for the list evaluation jobs method over gRPC.

        Lists all evaluation jobs within a project with
        possible filters. Pagination is supported.

        Returns:
            Callable[[~.ListEvaluationJobsRequest],
                    Awaitable[~.ListEvaluationJobsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_evaluation_jobs" not in self._stubs:
            self._stubs["list_evaluation_jobs"] = self.grpc_channel.unary_unary(
                "/google.cloud.datalabeling.v1beta1.DataLabelingService/ListEvaluationJobs",
                request_serializer=data_labeling_service.ListEvaluationJobsRequest.serialize,
                response_deserializer=data_labeling_service.ListEvaluationJobsResponse.deserialize,
            )
        return self._stubs["list_evaluation_jobs"]


__all__ = ("DataLabelingServiceGrpcAsyncIOTransport",)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.data_labeling_service import DataLabelingServiceClient
from .services.data_labeling_service import DataLabelingServiceAsyncClient

from .types.annotation import Annotation
from .types.annotation import AnnotationMetadata
from .types.annotation import AnnotationValue
from .types.annotation import BoundingPoly
from .types.annotation import ImageBoundingPolyAnnotation
from .types.annotation import ImageClassificationAnnotation
from .types.annotation import ImagePolylineAnnotation
from .types.annotation import ImageSegmentationAnnotation
from .types.annotation import NormalizedBoundingPoly
from .types.annotation import NormalizedPolyline
from .types.annotation import NormalizedVertex
from .types.annotation import ObjectTrackingFrame
from .types.annotation import OperatorMetadata
from .types.annotation import Polyline
from .types.annotation import SequentialSegment
from .types.annotation import TextClassificationAnnotation
from .types.annotation import TextEntityExtractionAnnotation
from .types.annotation import TimeSegment
from .types.annotation import Vertex
from .types.annotation import VideoClassificationAnnotation
from .types.annotation import VideoEventAnnotation
from .types.annotation import VideoObjectTrackingAnnotation
from .types.annotation import AnnotationSentiment
from .types.annotation import AnnotationSource
from .types.annotation import AnnotationType
from .types.annotation_spec_set import AnnotationSpec
from .types.annotation_spec_set import AnnotationSpecSet
from .types.data_labeling_service import CreateAnnotationSpecSetRequest
from .types.data_labeling_service import CreateDatasetRequest
from .types.data_labeling_service import CreateEvaluationJobRequest
from .types.data_labeling_service import CreateInstructionRequest
from .types.data_labeling_service import DeleteAnnotatedDatasetRequest
from .types.data_labeling_service import DeleteAnnotationSpecSetRequest
from .types.data_labeling_service import DeleteDatasetRequest
from .types.data_labeling_service import DeleteEvaluationJobRequest
from .types.data_labeling_service import DeleteInstructionRequest
from .types.data_labeling_service import ExportDataRequest
from .types.data_labeling_service import GetAnnotatedDatasetRequest
from .types.data_labeling_service import GetAnnotationSpecSetRequest
from .types.data_labeling_service import GetDataItemRequest
from .types.data_labeling_service import GetDatasetRequest
from .types.data_labeling_service import GetEvaluationJobRequest
from .types.data_labeling_service import GetEvaluationRequest
from .types.data_labeling_service import GetExampleRequest
from .types.data_labeling_service import GetInstructionRequest
from .types.data_labeling_service import ImportDataRequest
from .types.data_labeling_service import LabelImageRequest
from .types.data_labeling_service import LabelTextRequest
from .types.data_labeling_service import LabelVideoRequest
from .types.data_labeling_service import ListAnnotatedDatasetsRequest
from .types.data_labeling_service import ListAnnotatedDatasetsResponse
from .types.data_labeling_service import ListAnnotationSpecSetsRequest
from .types.data_labeling_service import ListAnnotationSpecSetsResponse
from .types.data_labeling_service import ListDataItemsRequest
from .types.data_labeling_service import ListDataItemsResponse
from .types.data_labeling_service import ListDatasetsRequest
from .types.data_labeling_service import ListDatasetsResponse
from .types.data_labeling_service import ListEvaluationJobsRequest
from .types.data_labeling_service import ListEvaluationJobsResponse
from .types.data_labeling_service import ListExamplesRequest
from .types.data_labeling_service import ListExamplesResponse
from .types.data_labeling_service import ListInstructionsRequest
from .types.data_labeling_service import ListInstructionsResponse
from .types.data_labeling_service import PauseEvaluationJobRequest
from .types.data_labeling_service import ResumeEvaluationJobRequest
from .types.data_labeling_service import SearchEvaluationsRequest
from .types.data_labeling_service import SearchEvaluationsResponse
from .types.data_labeling_service import SearchExampleComparisonsRequest
from .types.data_labeling_service import SearchExampleComparisonsResponse
from .types.data_labeling_service import UpdateEvaluationJobRequest
from .types.data_payloads import ImagePayload
from .types.data_payloads import TextPayload
from .types.data_payloads import VideoPayload
from .types.data_payloads import VideoThumbnail
from .types.dataset import AnnotatedDataset
from .types.dataset import AnnotatedDatasetMetadata
from .types.dataset import BigQuerySource
from .types.dataset import ClassificationMetadata
from .types.dataset import DataItem
from .types.dataset import Dataset
from .types.dataset import Example
from .types.dataset import GcsDestination
from .types.dataset import GcsFolderDestination
from .types.dataset import GcsSource
from .types.dataset import InputConfig
from .types.dataset import LabelStats
from .types.dataset import OutputConfig
from .types.dataset import TextMetadata
from .types.dataset import DataType
from .types.evaluation import BoundingBoxEvaluationOptions
from .types.evaluation import ClassificationMetrics
from .types.evaluation import ConfusionMatrix
from .types.evaluation import Evaluation
from .types.evaluation import EvaluationConfig
from .types.evaluation import EvaluationMetrics
from .types.evaluation import ObjectDetectionMetrics
from .types.evaluation import PrCurve
from .types.evaluation_job import Attempt
from .types.evaluation_job import EvaluationJob
from .types.evaluation_job import EvaluationJobAlertConfig
from .types.evaluation_job import EvaluationJobConfig
from .types.human_annotation_config import BoundingPolyConfig
from .types.human_annotation_config import EventConfig
from .types.human_annotation_config import HumanAnnotationConfig
from .types.human_annotation_config import ImageClassificationConfig
from .types.human_annotation_config import ObjectDetectionConfig
from .types.human_annotation_config import ObjectTrackingConfig
from .types.human_annotation_config import PolylineConfig
from .types.human_annotation_config import SegmentationConfig
from .types.human_annotation_config import SentimentConfig
from .types.human_annotation_config import TextClassificationConfig
from .types.human_annotation_config import TextEntityExtractionConfig
from .types.human_annotation_config import VideoClassificationConfig
from .types.human_annotation_config import StringAggregationType
from .types.instruction import CsvInstruction
from .types.instruction import Instruction
from .types.instruction import PdfInstruction
from .types.operations import CreateInstructionMetadata
from .types.operations import ExportDataOperationMetadata
from .types.operations import ExportDataOperationResponse
from .types.operations import ImportDataOperationMetadata
from .types.operations import ImportDataOperationResponse
from .types.operations import LabelImageBoundingBoxOperationMetadata
from .types.operations import LabelImageBoundingPolyOperationMetadata
from .types.operations import LabelImageClassificationOperationMetadata
from .types.operations import LabelImageOrientedBoundingBoxOperationMetadata
from .types.operations import LabelImagePolylineOperationMetadata
from .types.operations import LabelImageSegmentationOperationMetadata
from .types.operations import LabelOperationMetadata
from .types.operations import LabelTextClassificationOperationMetadata
from .types.operations import LabelTextEntityExtractionOperationMetadata
from .types.operations import LabelVideoClassificationOperationMetadata
from .types.operations import LabelVideoEventOperationMetadata
from .types.operations import LabelVideoObjectDetectionOperationMetadata
from .types.operations import LabelVideoObjectTrackingOperationMetadata

__all__ = (
    "DataLabelingServiceAsyncClient",
    "AnnotatedDataset",
    "AnnotatedDatasetMetadata",
    "Annotation",
    "AnnotationMetadata",
    "AnnotationSentiment",
    "AnnotationSource",
    "AnnotationSpec",
    "AnnotationSpecSet",
    "AnnotationType",
    "AnnotationValue",
    "Attempt",
    "BigQuerySource",
    "BoundingBoxEvaluationOptions",
    "BoundingPoly",
    "BoundingPolyConfig",
    "ClassificationMetadata",
    "ClassificationMetrics",
    "ConfusionMatrix",
    "CreateAnnotationSpecSetRequest",
    "CreateDatasetRequest",
    "CreateEvaluationJobRequest",
    "CreateInstructionMetadata",
    "CreateInstructionRequest",
    "CsvInstruction",
    "DataItem",
    "DataLabelingServiceClient",
    "DataType",
    "Dataset",
    "DeleteAnnotatedDatasetRequest",
    "DeleteAnnotationSpecSetRequest",
    "DeleteDatasetRequest",
    "DeleteEvaluationJobRequest",
    "DeleteInstructionRequest",
    "Evaluation",
    "EvaluationConfig",
    "EvaluationJob",
    "EvaluationJobAlertConfig",
    "EvaluationJobConfig",
    "EvaluationMetrics",
    "EventConfig",
    "Example",
    "ExportDataOperationMetadata",
    "ExportDataOperationResponse",
    "ExportDataRequest",
    "GcsDestination",
    "GcsFolderDestination",
    "GcsSource",
    "GetAnnotatedDatasetRequest",
    "GetAnnotationSpecSetRequest",
    "GetDataItemRequest",
    "GetDatasetRequest",
    "GetEvaluationJobRequest",
    "GetEvaluationRequest",
    "GetExampleRequest",
    "GetInstructionRequest",
    "HumanAnnotationConfig",
    "ImageBoundingPolyAnnotation",
    "ImageClassificationAnnotation",
    "ImageClassificationConfig",
    "ImagePayload",
    "ImagePolylineAnnotation",
    "ImageSegmentationAnnotation",
    "ImportDataOperationMetadata",
    "ImportDataOperationResponse",
    "ImportDataRequest",
    "InputConfig",
    "Instruction",
    "LabelImageBoundingBoxOperationMetadata",
    "LabelImageBoundingPolyOperationMetadata",
    "LabelImageClassificationOperationMetadata",
    "LabelImageOrientedBoundingBoxOperationMetadata",
    "LabelImagePolylineOperationMetadata",
    "LabelImageRequest",
    "LabelImageSegmentationOperationMetadata",
    "LabelOperationMetadata",
    "LabelStats",
    "LabelTextClassificationOperationMetadata",
    "LabelTextEntityExtractionOperationMetadata",
    "LabelTextRequest",
    "LabelVideoClassificationOperationMetadata",
    "LabelVideoEventOperationMetadata",
    "LabelVideoObjectDetectionOperationMetadata",
    "LabelVideoObjectTrackingOperationMetadata",
    "LabelVideoRequest",
    "ListAnnotatedDatasetsRequest",
    "ListAnnotatedDatasetsResponse",
    "ListAnnotationSpecSetsRequest",
    "ListAnnotationSpecSetsResponse",
    "ListDataItemsRequest",
    "ListDataItemsResponse",
    "ListDatasetsRequest",
    "ListDatasetsResponse",
    "ListEvaluationJobsRequest",
    "ListEvaluationJobsResponse",
    "ListExamplesRequest",
    "ListExamplesResponse",
    "ListInstructionsRequest",
    "ListInstructionsResponse",
    "NormalizedBoundingPoly",
    "NormalizedPolyline",
    "NormalizedVertex",
    "ObjectDetectionConfig",
    "ObjectDetectionMetrics",
    "ObjectTrackingConfig",
    "ObjectTrackingFrame",
    "OperatorMetadata",
    "OutputConfig",
    "PauseEvaluationJobRequest",
    "PdfInstruction",
    "Polyline",
    "PolylineConfig",
    "PrCurve",
    "ResumeEvaluationJobRequest",
    "SearchEvaluationsRequest",
    "SearchEvaluationsResponse",
    "SearchExampleComparisonsRequest",
    "SearchExampleComparisonsResponse",
    "SegmentationConfig",
    "SentimentConfig",
    "SequentialSegment",
    "StringAggregationType",
    "TextClassificationAnnotation",
    "TextClassificationConfig",
    "TextEntityExtractionAnnotation",
    "TextEntityExtractionConfig",
    "TextMetadata",
    "TextPayload",
    "TimeSegment",
    "UpdateEvaluationJobRequest",
    "Vertex",
    "VideoClassificationAnnotation",
    "VideoClassificationConfig",
    "VideoEventAnnotation",
    "VideoObjectTrackingAnnotation",
    "VideoPayload",
    "VideoThumbnail",
)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.datalabeling_v1beta1.types import dataset
from google.cloud.datalabeling_v1beta1.types import evaluation
from google.cloud.datalabeling_v1beta1.types import (
    human_annotation_config as gcd_human_annotation_config,
)
from google.protobuf import timestamp_pb2  # type: ignore
from google.rpc import status_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.datalabeling.v1beta1",
    manifest={
        "EvaluationJob",
        "EvaluationJobConfig",
        "EvaluationJobAlertConfig",
        "Attempt",
    },
)


class EvaluationJob(proto.Message):
    r"""Defines an evaluation job that runs periodically to generate
    [Evaluations][google.cloud.datalabeling.v1beta1.Evaluation].
    `Creating an evaluation
    job </ml-engine/docs/continuous-evaluation/create-job>`__ is the
    starting point for using continuous evaluation.

    Attributes:
        name (str):
            Output only. After you create a job, Data Labeling Service
            assigns a name to the job with the following format:

            "projects/{project_id}/evaluationJobs/{evaluation_job_id}".
        description (str):
            Required. Description of the job. The
            description can be up to 25,000 characters long.
        state (google.cloud.datalabeling_v1beta1.types.EvaluationJob.State):
            Output only. Describes the current state of
            the job.
        schedule (str):
            Required. Describes the interval at which the job runs. This
            interval must be at least 1 day, and it is rounded to the
            nearest day. For example, if you specify a 50-hour interval,
            the job runs every 2 days.

            You can provide the schedule in `crontab
            format </scheduler/docs/configuring/cron-job-schedules>`__
            or in an `English-like
            format </appengine/docs/standard/python/config/cronref#schedule_format>`__.

            Regardless of what you specify, the job will run at 10:00 AM
            UTC. Only the interval from this schedule is used, not the
            specific time of day.
        model_version (str):
            Required. The `AI Platform Prediction model
            version </ml-engine/docs/prediction-overview>`__ to be
            evaluated. Prediction input and output is sampled from this
            model version. When creating an evaluation job, specify the
            model version in the following format:

            "projects/{project_id}/models/{model_name}/versions/{version_name}"

            There can only be one evaluation job per model version.
        evaluation_job_config (google.cloud.datalabeling_v1beta1.types.EvaluationJobConfig):
            Required. Configuration details for the
            evaluation job.
        annotation_spec_set (str):
            Required. Name of the
            [AnnotationSpecSet][google.cloud.datalabeling.v1beta1.AnnotationSpecSet]
            describing all the labels that your machine learning model
            outputs. You must create this resource before you create an
            evaluation job and provide its name in the following format:

            "projects/{project_id}/annotationSpecSets/{annotation_spec_set_id}".
        label_missing_ground_truth (bool):
            Required. Whether you want Data Labeling Service to provide
            ground truth labels for prediction input. If you want the
            service to assign human labelers to annotate your data, set
            this to ``true``. If you want to provide your own ground
            truth labels in the evaluation job's BigQuery table, set
            this to ``false``.
        attempts (Sequence[google.cloud.datalabeling_v1beta1.types.Attempt]):
            Output only. Every time the evaluation job
            runs and an error occurs, the failed attempt is
            appended to this array.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Timestamp of when this
            evaluation job was created.
    """

    class State(proto.Enum):
        r"""State of the job."""
        STATE_UNSPECIFIED = 0
        SCHEDULED = 1
        RUNNING = 2
        PAUSED = 3
        STOPPED = 4

    name = proto.Field(proto.STRING, number=1,)
    description = proto.Field(proto.STRING, number=2,)
    state = proto.Field(proto.ENUM, number=3, enum=State,)
    schedule = proto.Field(proto.STRING, number=4,)
    model_version = proto.Field(proto.STRING, number=5,)
    evaluation_job_config = proto.Field(
        proto.MESSAGE, number=6, message="EvaluationJobConfig",
    )
    annotation_spec_set = proto.Field(proto.STRING, number=7,)
    label_missing_ground_truth = proto.Field(proto.BOOL, number=8,)
    attempts = proto.RepeatedField(proto.MESSAGE, number=9, message="Attempt",)
    create_time = proto.Field(
        proto.MESSAGE, number=10, message=timestamp_pb2.Timestamp,
    )


class EvaluationJobConfig(proto.Message):
    r"""Configures specific details of how a continuous evaluation
    job works. Provide this configuration when you create an
    EvaluationJob.

    Attributes:
        image_classification_config (google.cloud.datalabeling_v1beta1.types.ImageClassificationConfig):
            Specify this field if your model version performs image
            classification or general classification.

            ``annotationSpecSet`` in this configuration must match
            [EvaluationJob.annotationSpecSet][google.cloud.datalabeling.v1beta1.EvaluationJob.annotation_spec_set].
            ``allowMultiLabel`` in this configuration must match
            ``classificationMetadata.isMultiLabel`` in
            [input_config][google.cloud.datalabeling.v1beta1.EvaluationJobConfig.input_config].
        bounding_poly_config (google.cloud.datalabeling_v1beta1.types.BoundingPolyConfig):
            Specify this field if your model version performs image
            object detection (bounding box detection).

            ``annotationSpecSet`` in this configuration must match
            [EvaluationJob.annotationSpecSet][google.cloud.datalabeling.v1beta1.EvaluationJob.annotation_spec_set].
        text_classification_config (google.cloud.datalabeling_v1beta1.types.TextClassificationConfig):
            Specify this field if your model version performs text
            classification.

            ``annotationSpecSet`` in this configuration must match
            [EvaluationJob.annotationSpecSet][google.cloud.datalabeling.v1beta1.EvaluationJob.annotation_spec_set].
            ``allowMultiLabel`` in this configuration must match
            ``classificationMetadata.isMultiLabel`` in
            [input_config][google.cloud.datalabeling.v1beta1.EvaluationJobConfig.input_config].
        input_config (google.cloud.datalabeling_v1beta1.types.InputConfig):
            Rquired. Details for the sampled prediction input. Within
            this configuration, there are requirements for several
            fields:

            -  ``dataType`` must be one of ``IMAGE``, ``TEXT``, or
               ``GENERAL_DATA``.
            -  ``annotationType`` must be one of
               ``IMAGE_CLASSIFICATION_ANNOTATION``,
               ``TEXT_CLASSIFICATION_ANNOTATION``,
               ``GENERAL_CLASSIFICATION_ANNOTATION``, or
               ``IMAGE_BOUNDING_BOX_ANNOTATION`` (image object
               detection).
            -  If your machine learning model performs classification,
               you must specify ``classificationMetadata.isMultiLabel``.
            -  You must specify ``bigquerySource`` (not ``gcsSource``).
        evaluation_config (google.cloud.datalabeling_v1beta1.types.EvaluationConfig):
            Required. Details for calculating evaluation metrics and
            creating
            [Evaulations][google.cloud.datalabeling.v1beta1.Evaluation].
            If your model version performs image object detection, you
            must specify the ``boundingBoxEvaluationOptions`` field
            within this configuration. Otherwise, provide an empty
            object for this configuration.
        human_annotation_config (google.cloud.datalabeling_v1beta1.types.HumanAnnotationConfig):
            Optional. Details for human annotation of your data. If you
            set
            [labelMissingGroundTruth][google.cloud.datalabeling.v1beta1.EvaluationJob.label_missing_ground_truth]
            to ``true`` for this evaluation job, then you must specify
            this field. If you plan to provide your own ground truth
            labels, then omit this field.

            Note that you must create an
            [Instruction][google.cloud.datalabeling.v1beta1.Instruction]
            resource before you can specify this field. Provide the name
            of the instruction resource in the ``instruction`` field
            within this configuration.
        bigquery_import_keys (Sequence[google.cloud.datalabeling_v1beta1.types.EvaluationJobConfig.BigqueryImportKeysEntry]):
            Required. Prediction keys that tell Data Labeling Service
            where to find the data for evaluation in your BigQuery
            table. When the service samples prediction input and output
            from your model version and saves it to BigQuery, the data
            gets stored as JSON strings in the BigQuery table. These
            keys tell Data Labeling Service how to parse the JSON.

            You can provide the following entries in this field:

            -  ``data_json_key``: the data key for prediction input. You
               must provide either this key or ``reference_json_key``.
            -  ``reference_json_key``: the data reference key for
               prediction input. You must provide either this key or
               ``data_json_key``.
            -  ``label_json_key``: the label key for prediction output.
               Required.
            -  ``label_score_json_key``: the score key for prediction
               output. Required.
            -  ``bounding_box_json_key``: the bounding box key for
               prediction output. Required if your model version perform
               image object detection.

            Learn `how to configure prediction
            keys </ml-engine/docs/continuous-evaluation/create-job#prediction-keys>`__.
        example_count (int):
            Required. The maximum number of predictions to sample and
            save to BigQuery during each [evaluation
            interval][google.cloud.datalabeling.v1beta1.EvaluationJob.schedule].
            This limit overrides ``example_sample_percentage``: even if
            the service has not sampled enough predictions to fulfill
            ``example_sample_perecentage`` during an interval, it stops
            sampling predictions when it meets this limit.
        example_sample_percentage (float):
            Required. Fraction of predictions to sample and save to
            BigQuery during each [evaluation
            interval][google.cloud.datalabeling.v1beta1.EvaluationJob.schedule].
            For example, 0.1 means 10% of predictions served by your
            model version get saved to BigQuery.
        evaluation_job_alert_config (google.cloud.datalabeling_v1beta1.types.EvaluationJobAlertConfig):
            Optional. Configuration details for
            evaluation job alerts. Specify this field if you
            want to receive email alerts if the evaluation
            job finds that your predictions have low mean
            average precision during a run.
    """

    image_classification_config = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="human_annotation_request_config",
        message=gcd_human_annotation_config.ImageClassificationConfig,
    )
    bounding_poly_config = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="human_annotation_request_config",
        message=gcd_human_annotation_config.BoundingPolyConfig,
    )
    text_classification_config = proto.Field(
        proto.MESSAGE,
        number=8,
        oneof="human_annotation_request_config",
        message=gcd_human_annotation_config.TextClassificationConfig,
    )
    input_config = proto.Field(proto.MESSAGE, number=1, message=dataset.InputConfig,)
    evaluation_config = proto.Field(
        proto.MESSAGE, number=2, message=evaluation.EvaluationConfig,
    )
    human_annotation_config = proto.Field(
        proto.MESSAGE,
        number=3,
        message=gcd_human_annotation_config.HumanAnnotationConfig,
    )
    bigquery_import_keys = proto.MapField(proto.STRING, proto.STRING, number=9,)
    example_count = proto.Field(proto.INT32, number=10,)
    example_sample_percentage = proto.Field(proto.DOUBLE, number=11,)
    evaluation_job_alert_config = proto.Field(
        proto.MESSAGE, number=13, message="EvaluationJobAlertConfig",
    )


class EvaluationJobAlertConfig(proto.Message):
    r"""Provides details for how an evaluation job sends email alerts
    based on the results of a run.

    Attributes:
        email (str):
            Required. An email address to send alerts to.
        min_acceptable_mean_average_precision (float):
            Required. A number between 0 and 1 that describes a minimum
            mean average precision threshold. When the evaluation job
            runs, if it calculates that your model version's predictions
            from the recent interval have
            [meanAveragePrecision][google.cloud.datalabeling.v1beta1.PrCurve.mean_average_precision]
            below this threshold, then it sends an alert to your
            specified email.
    """

    email = proto.Field(proto.STRING, number=1,)
    min_acceptable_mean_average_precision = proto.Field(proto.DOUBLE, number=2,)


class Attempt(proto.Message):
    r"""Records a failed evaluation job run.
    Attributes:
        attempt_time (google.protobuf.timestamp_pb2.Timestamp):

        partial_failures (Sequence[google.rpc.status_pb2.Status]):
            Details of errors that occurred.
    """

    attempt_time = proto.Field(
        proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,
    )
    partial_failures = proto.RepeatedField(
        proto.MESSAGE, number=2, message=status_pb2.Status,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
